@@ -89,38 +89,40 @@ def send_sms():
 
     if telma:
         LOGS.logger.info("MSISDN Telma redirected to Orange SMPP.")
-        queue = CONFIG['orange']['account']
+        sender_id = "orange"
     elif not telma and json_doc.get('sender_id') == 'orange':
         LOGS.logger.warning(
             "MSISDN '{}' is not Telma but targeting Orange SMPP. "
             "Redirected to default SMPP."
             .format(msisdn)
         )
-        queue = CONFIG['Blueline']['account']
+        sender_id = "Blueline"
     else:
         if user.startswith('partenaire'):
             sender_id = user.split('_')[1]
         else:
             sender_id = json_doc.get('sender_id', 'bip')
-        try:
-            logging.warn(sender_id)
-            json_doc['sender_id'] = sender_id
-            queue = CONFIG[sender_id]['account']
-        except KeyError:
-            return bad_request(
-                message="Le sender_id n'exist pas",
-                code='{}-{}'.format(
-                    SERVICE_CODE,
-                    '4001'
-                    ),
-                service_code=SERVICE_CODE
-                )
+
+    try:
+        json_doc['sender_id'] = sender_id
+        queue = CONFIG[sender_id]['account']
+    except KeyError:
+        return bad_request(
+            message="Le sender_id n'exist pas",
+            code='{}-{}'.format(
+                SERVICE_CODE,
+                '4001'
+                ),
+            service_code=SERVICE_CODE
+            )
+
     document = {
         'auth': auth or (),
         'params': params,
         'headers': headers,
         'json': json_doc
         }
+
     try:
         connection = pika.BlockingConnection(
             pika.ConnectionParameters(
